@@ -82,7 +82,7 @@ public:
     /**
      * Deletes the Element instance.
      */
-    ~Element();
+    ~Element() override;
 
     /**
      * Computes an action on a collision with the Kapman.
@@ -144,7 +144,7 @@ public:
     */
     void initCoordinate();
 
-signals:
+Q_SIGNALS:
 
     /**
      * Emitted on Element move.
