@@ -50,7 +50,7 @@ public:
     /**
      * Deletes the ElementItem instance.
      */
-    ~ElementItem();
+    ~ElementItem() override;
 
     /**
      * Gets the Element model.
@@ -63,7 +63,7 @@ public:
      */
     QPainterPath shape() const override;
 
-public slots:
+public Q_SLOTS:
 
     /**
      * Updates the ElementItem coordinates.
