@@ -43,7 +43,7 @@ public:
     /**
      * Deletes the GameView instance.
      */
-    ~GameView();
+    ~GameView() override;
 
     /**
      * Resizes the items when the view is resized.
@@ -65,7 +65,7 @@ protected:
      */
     void focusOutEvent(QFocusEvent *p_event) override;
 
-signals:
+Q_SIGNALS:
 
     /**
      * Emitted on key press event for the Game instance
