@@ -46,14 +46,14 @@ public:
     /**
      * Deletes the CharacterItem instance.
      */
-    ~GhostItem();
+    ~GhostItem() override;
 
     /**
      * Ensures the blink timers are correctly set
      */
     void updateBlinkTimersDuration();
 
-public slots:
+public Q_SLOTS:
 
     /**
      * Updates the view coordinates.
