@@ -20,7 +20,6 @@
 #include "pill.h"
 #include "energizer.h"
 #include <QDebug>
-#include <QXmlStreamAttributes>
 
 KapmanParser::KapmanParser(Game *p_game)
 {
@@ -66,7 +65,7 @@ bool KapmanParser::parse(QIODevice *input)
         }
     }
 
-    if (reader.isEndDocument())
+    if (!reader.isEndDocument())
         return false;
 
     return true;
